# - Try to find the OpenSSL encryption library
# Once done this will define
#
#  OPENSSL_FOUND - system has the OpenSSL library
#  OPENSSL_INCLUDE_DIR - the OpenSSL include directory
#  OPENSSL_LIBRARIES - The libraries needed to use OpenSSL

# Copyright (c) 2006, Alexander Neundorf, <neundorf@kde.org>
#
# Redistribution and use is allowed according to the terms of the BSD license.
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.


if(OPENSSL_LIBRARIES)
  set(OpenSSL_FIND_QUIETLY TRUE)
endif(OPENSSL_LIBRARIES)

if(SSL_EAY_DEBUG AND SSL_EAY_RELEASE)
  set(LIB_FOUND 1)
endif(SSL_EAY_DEBUG AND SSL_EAY_RELEASE)

set(OPENSSL_PATH)
if(MSVC80)
  set(OPENSSL_PATH ${PROJECT_SOURCE_DIR}/../openssl/lib-vs2005)
elseif(MSVC90)
  set(OPENSSL_PATH ${PROJECT_SOURCE_DIR}/../openssl/lib-vs2008)
elseif(MSVC60)
  set(OPENSSL_PATH ${PROJECT_SOURCE_DIR}/../openssl/lib-vs6)
elseif(MINGW)
  set(OPENSSL_PATH ${PROJECT_SOURCE_DIR}/../openssl/lib-vs6)
endif(MSVC80)

find_path(OPENSSL_INCLUDE_DIR openssl/ssl.h  PATHS ${OPENSSL_PATH}/../include)
#message("OPENSSL_PATH: ${OPENSSL_PATH}")
#message("OPENSSL_INCLUDE_DIR: ${OPENSSL_INCLUDE_DIR}")

find_library(SSL_CRYPTO   NAMES crypto    PATHS ${OPENSSL_PATH})
find_library(SSL_LIBRARY1 NAMES ssl       PATHS ${OPENSSL_PATH})
find_library(SSL_LIBRARY2 NAMES ssleay32.a ssleay32 PATHS ${OPENSSL_PATH})
find_library(SSL_LIBRARY3 NAMES libeay32.a libeay32 PATHS ${OPENSSL_PATH})

if( SSL_LIBRARY2 AND SSL_LIBRARY3 )
  set(OPENSSL_LIBRARIES "${SSL_LIBRARY2};${SSL_LIBRARY3}" CACHE STRING "Path to a library." FORCE)
elseif( SSL_CRYPTO AND SSL_LIBRARY1 )
  set(OPENSSL_LIBRARIES "${SSL_CRYPTO};${SSL_LIBRARY1}" CACHE STRING "Path to a library." FORCE)
endif( SSL_LIBRARY2 AND SSL_LIBRARY3 )

if(OPENSSL_INCLUDE_DIR AND OPENSSL_LIBRARIES)
   set(OPENSSL_FOUND TRUE)
else(OPENSSL_INCLUDE_DIR AND OPENSSL_LIBRARIES)
   set(OPENSSL_FOUND FALSE)
endif (OPENSSL_INCLUDE_DIR AND OPENSSL_LIBRARIES)

if (OPENSSL_FOUND)
   if (NOT OpenSSL_FIND_QUIETLY)
      message(STATUS "Found OpenSSL: ${OPENSSL_LIBRARIES}")
   endif (NOT OpenSSL_FIND_QUIETLY)
else (OPENSSL_FOUND)
   if (OpenSSL_FIND_REQUIRED)
      message(FATAL_ERROR "Could NOT find OpenSSL")
   endif (OpenSSL_FIND_REQUIRED)
endif (OPENSSL_FOUND)

mark_as_advanced(OPENSSL_INCLUDE_DIR OPENSSL_LIBRARIES)

